pub struct AccessMask(/* private fields */);Expand description
ACCESS_MASK bits (MS-DTYP 2.4.3 + AD-specific extended rights).
Implementations
Sourceimpl AccessMask
impl AccessMask
pub const CREATE_CHILD: Self
pub const DELETE_CHILD: Self
pub const LIST_CHILDREN: Self
pub const SELF: Self
pub const READ_PROP: Self
pub const WRITE_PROP: Self
pub const DELETE_TREE: Self
pub const LIST_OBJECT: Self
pub const CONTROL_ACCESS: Self
pub const DELETE: Self
pub const READ_CONTROL: Self
pub const WRITE_DAC: Self
pub const WRITE_OWNER: Self
pub const SYNCHRONIZE: Self
pub const ACCESS_SYSTEM_SECURITY: Self
pub const GENERIC_ALL: Self
pub const GENERIC_EXECUTE: Self
pub const GENERIC_WRITE: Self
pub const GENERIC_READ: Self
Sourceimpl AccessMask
impl AccessMask
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Examples found in repository?
9fn main() {
10 let bytes = match std::env::args().nth(1) {
11 Some(hex) => (0..hex.len())
12 .step_by(2)
13 .map(|i| u8::from_str_radix(&hex[i..i + 2], 16).expect("hex"))
14 .collect::<Vec<u8>>(),
15 None => {
16 windows_sddl::build_rbcd_sd(&windows_sddl::Sid::parse("S-1-5-21-1-2-3-1104").unwrap())
17 }
18 };
19
20 let sd = parse(&bytes).expect("parse security descriptor");
21 if let Some(o) = &sd.owner {
22 println!("owner: {o}");
23 }
24 for ace in sd.dacl.iter().flat_map(|d| &d.aces) {
25 if !ace.is_allow() {
26 continue;
27 }
28 let mut notes = Vec::new();
29 if ace.mask.contains(AccessMask::GENERIC_ALL) {
30 notes.push("GenericAll".to_string());
31 }
32 if ace.mask.contains(AccessMask::WRITE_DAC) {
33 notes.push("WriteDacl".to_string());
34 }
35 if ace.mask.contains(AccessMask::WRITE_OWNER) {
36 notes.push("WriteOwner".to_string());
37 }
38 if let Some(g) = &ace.object_type {
39 if rights::is_dcsync_right(g) {
40 notes.push("DCSync".to_string());
41 }
42 if rights::is_enrollment_right(g) {
43 notes.push("Cert-Enrollment".to_string());
44 }
45 if rights::KEY_CREDENTIAL_LINK.matches(g) {
46 notes.push("Shadow-Credentials".to_string());
47 }
48 if rights::RBCD_ATTR.matches(g) {
49 notes.push("RBCD".to_string());
50 }
51 }
52 if !notes.is_empty() {
53 println!(" {} → {}", ace.trustee, notes.join(", "));
54 }
55 }
56}Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AccessMask
impl AccessMask
Sourcepub const fn iter(&self) -> Iter<AccessMask>
pub const fn iter(&self) -> Iter<AccessMask>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AccessMask>
pub const fn iter_names(&self) -> IterNames<AccessMask>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.